@@ -129,8 +129,7 @@ def save_config(update=False):
     with open(config_path + '/config.yml', 'w') as w:
         w.write(yaml.dump(setup_config))
 
-    if(update == False):
-        _generate_autocomplete_script(crawler_paths)
+    _generate_autocomplete_script(crawler_paths)
 
 
 def _yes_no_prompt(ques):
@@ -151,16 +150,20 @@ def _generate_autocomplete_script(crawler_paths):
         d['dest_path'] = crawler_paths[p]
         data['paths'].append(d)
 
-    if path.exists(config_path + '/autocomplete.sh'):
-        remove(config_path +
-               '/autocomplete.sh')
-
     template_dir = Path(__file__).parent.parent.absolute()
-    template_file = '{}/templates/{}'.format(
-        template_dir, 'autocomplete.jinja2')
+    
+    # generate autocomplete file for zsh and bash 
+    for auto_script in ['autocomplete',  'autocomplete_zsh']:
 
-    with open(template_file) as file:
-        template = Template(file.read())
+        if path.exists(config_path + f'/{auto_script}.sh'):
+            remove(config_path +
+                   f'/{auto_script}.sh')
 
-    with open(config_path + '/autocomplete.sh', 'w') as dest_file:
-        dest_file.write(template.render(data))
+        template_file = '{}/templates/{}'.format(
+            template_dir, f'{auto_script}.jinja2')
+
+        with open(template_file) as file:
+            template = Template(file.read())
+
+        with open(config_path + f'/{auto_script}.sh', 'w') as dest_file:
+            dest_file.write(template.render(data))
